==> petals-view-ui-1.0-sources.jar: com/ebmwebsourcing/petalsview/gui/beans/supervision/ListOfFlows.java <==
/**
 * Petals View - Functional Supervision.
 * Copyright (c) 2010 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * ListOfFlows.java
 * -------------------------------------------------------------------------
 */

package com.ebmwebsourcing.petalsview.gui.beans.supervision;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

import org.ow2.opensuit.core.validation.LocalizedValidationError;
import org.ow2.opensuit.core.validation.ValidationErrors;

import com.ebmwebsourcing.petalsview.persistence.model.flow.Flow;
import com.ebmwebsourcing.petalsview.service.flow.FlowManager;
import com.ebmwebsourcing.petalsview.util.PetalsViewServiceFactory;

public class ListOfFlows {
    private static int[] ALL_STATUS = { 0 /* success */, 1 /* error */, 2 /*
                                                                           * in
                                                                           * progress
                                                                           */};

    private List<Flow> flows;

    private Date before;

    private Date after;

    private FlowManager flowManager;

    // private FlowRefManager flowRefManager;

    public ListOfFlows() {
        super();
        this.flowManager = PetalsViewServiceFactory.getInstance().getFlowManager();
        // this.flowRefManager =
        // PetalsViewServiceFactory.getInstance().getFlowRefManager();
    }

    // ===============================================================
    // === control methods
    // ===============================================================
    public void loadAll() throws Exception {
        setupFilterToday();

        flows = flowManager.loadAllStartedWithDateFilter(after, before);
    }

    private void setupFilterToday() {
        // --- initialize date filter to today
        Calendar cal = Calendar.getInstance();
        cal.set(Calendar.HOUR_OF_DAY, 0);
        cal.set(Calendar.MINUTE, 0);
        cal.set(Calendar.SECOND, 0);
        cal.set(Calendar.MILLISECOND, 0);
        after = cal.getTime();
        cal.add(Calendar.DATE, 1);
        before = cal.getTime();
    }

    public String getShortName(Flow flow) {

        String shortName = flow.getIdpetals();

        if (shortName != null) {

            if (shortName.length() > 30) {
                shortName = shortName.substring(0, 27) + "...";
            }
        } else {

            shortName = " ";
        }

        return shortName;
    }

    public String getName(Flow flow) {

        String name = flow.getIdpetals();
        return name;

    }

    public void viewAllFlow() throws Exception{
        after = null;
        before = null;
        flows = new ArrayList<Flow>();
        flows = flowManager.loadAll();
    }

    public void validateFilter() throws ValidationErrors {
        System.out.println("--> validate");
        Date now = new Date();
        ValidationErrors errors = new ValidationErrors();

        if (after != null && after.after(now)) {
            System.out.println("--> future");
            errors.addItemError("flows.after", new LocalizedValidationError(
                    "validation.date.future"));
        }

        if (before != null && after != null && after.after(before)) {
            System.out.println("--> negative range");
            errors.addItemError("flows.before", new LocalizedValidationError(
                    "validation.date.negative_range"));
        }

        if (errors.hasErrors()) {
            System.out.println("--> throw");
            throw errors;
        }
    }

    public void applyFilter() throws Exception{
        flows = flowManager.loadAllStartedWithDateFilter(after, before);
    }

    public void refresh() throws Exception{
        if (after == null && before == null)  {
            viewAllFlow();
        } else {
            setupFilterToday();
            flows = flowManager.loadAllStartedWithDateFilter(after, before);
        }
    }

    // ===============================================================
    // === setters/getters
    // ===============================================================

    public List<Flow> getFlows() {
        return flows;
    }

    public static int[] getAllStatus() {
        return ALL_STATUS;
    }

    public Date getBefore() {
        return before;
    }

    public void setBefore(Date before) {
        this.before = before;
    }

    public Date getAfter() {
        return after;
    }

    public void setAfter(Date after) {
        this.after = after;
    }

    /**
     * Convert a flow status into a ui status (in_progress = 2, success = 0,
     * failure = 1)
     * 
     * @param status
     * @return
     */
    public int getUiStatus(int status) {
        if (status == Flow.SUCCESS_STATUS)
            return 0;
        else if (status == Flow.IN_PROGRESS_STATUS)
            return 2;
        else
            return 1;
    }

}

==> petals-view-ui-1.1-sources.jar: com/ebmwebsourcing/petalsview/gui/beans/supervision/ListOfFlows.java <==
/**
 * Petals View - Functional Supervision.
 * Copyright (c) 2010 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * ListOfFlows.java
 * -------------------------------------------------------------------------
 */

package com.ebmwebsourcing.petalsview.gui.beans.supervision;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.DateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import java.util.Locale;

import javax.servlet.http.HttpServletResponse;

import org.ow2.opensuit.core.error.LocalizedError;
import org.ow2.opensuit.core.validation.LocalizedValidationError;
import org.ow2.opensuit.core.validation.ValidationErrors;

import com.ebmwebsourcing.petalsview.persistence.model.flow.Flow;
import com.ebmwebsourcing.petalsview.service.flow.FlowManager;
import com.ebmwebsourcing.petalsview.util.PetalsViewServiceFactory;

public class ListOfFlows {
    private static int[] ALL_STATUS = { 0 /* success */, 1 /* error */, 2 /*
                                                                           * in
                                                                           * progress
                                                                           */};

    private List<Flow> flows;

    private Date before;

    private Date after;

    private FlowManager flowManager;
    
    private String css;

    // private FlowRefManager flowRefManager;

    public ListOfFlows() {
        super();
        this.flowManager = PetalsViewServiceFactory.getInstance().getFlowManager();
        // this.flowRefManager =
        // PetalsViewServiceFactory.getInstance().getFlowRefManager();
    }

    // ===============================================================
    // === control methods
    // ===============================================================
    public void loadAll() throws Exception {
        setupFilterToday();

        flows = flowManager.loadAllStartedWithDateFilter(after, before);
    }

    private void setupFilterToday() {
        // --- initialize date filter to today
        Calendar cal = Calendar.getInstance();
        cal.set(Calendar.HOUR_OF_DAY, 0);
        cal.set(Calendar.MINUTE, 0);
        cal.set(Calendar.SECOND, 0);
        cal.set(Calendar.MILLISECOND, 0);
        after = cal.getTime();
        cal.add(Calendar.DATE, 1);
        before = cal.getTime();
    }

    public String getShortName(Flow flow) {

        String shortName = flow.getIdpetals();

        if (shortName != null) {

            if (shortName.length() > 30) {
                shortName = shortName.substring(0, 27) + "...";
            }
        } else {

            shortName = " ";
        }

        return shortName;
    }

    public String getName(Flow flow) {

        String name = flow.getIdpetals();
        return name;

    }

    public void viewAllFlow() throws Exception{
        after = null;
        before = null;
        flows = new ArrayList<Flow>();
        css="status_ok";
        flows = flowManager.loadAll();
    }

    public void validateFilter() throws ValidationErrors {
       // System.out.println("--> validate");
        Date now = new Date();
        ValidationErrors errors = new ValidationErrors();

        if (after != null && after.after(now)) {
          //  System.out.println("--> future");
            errors.addItemError("flows.after", new LocalizedValidationError(
                    "validation.date.future"));
        }

        if (before != null && after != null && after.after(before)) {
           // System.out.println("--> negative range");
            errors.addItemError("flows.before", new LocalizedValidationError(
                    "validation.date.negative_range"));
        }

        if (errors.hasErrors()) {
          //  System.out.println("--> throw");
            throw errors;
        }
    }

    public void applyFilter() throws Exception{
        flows = flowManager.loadAllStartedWithDateFilter(after, before);
    }

    public void refresh() throws Exception{
        if (after == null && before == null)  {
            viewAllFlow();
        } else {
            setupFilterToday();
            flows = flowManager.loadAllStartedWithDateFilter(after, before);
        }
    }
    
    public void download (HttpServletResponse response) throws LocalizedError, IOException {
		response.setContentType("text/csv");

		Locale locale = Locale.FRANCE;
		DateFormat dateFormat = DateFormat.getDateInstance(DateFormat.DATE_FIELD,
				locale);
		Date date = new Date();
		PrintWriter output = response.getWriter();

		try {
			output.print("Type ;");
			output.print("Instance ;");
			output.print("StartDate ;");
			output.print("EndDate ;");
			output.print("Status ;");
			output.println();
			for(Flow f : flows){
				output.print(f.getType() + ";");
				output.print(f.getId() +";");
				date.setTime(f.getStartDate());
				output.print(date +";");
				date.setTime(f.getEndDate());
				String dateS = dateFormat.format(date);
				output.print(dateS +";");
				int status = getUiStatus(f.getStatus());
				String s = null;
				if(status == 0){
					s="Success";
				}
				
				output.print(s +";");
				output.println();
			}
			
		} catch (Exception e) {
			
			throw new LocalizedError("database_technical", new Object[] { e
					.getMessage() });
		}

		output.flush();
		output.close();
	}
    
   
    // ===============================================================
    // === setters/getters
    // ===============================================================

    public List<Flow> getFlows() {
        return flows;
    }

    public static int[] getAllStatus() {
        return ALL_STATUS;
    }

    public Date getBefore() {
        return before;
    }

    public void setBefore(Date before) {
        this.before = before;
    }

    public Date getAfter() {
        return after;
    }

    public void setAfter(Date after) {
        this.after = after;
    }

    /**
     * Convert a flow status into a ui status (in_progress = 2, success = 0,
     * failure = 1)
     * 
     * @param status
     * @return
     */
    public int getUiStatus(int status) {
        if (status == Flow.SUCCESS_STATUS)
            return 0;
        else if (status == Flow.IN_PROGRESS_STATUS)
            return 2;
        else
            return 1;
    }

	public String getCss() {
		return css;
	}

	public void setCss(String css) {
		this.css = css;
	}

}
